@@ -33,6 +33,7 @@ from .exceptions import InvalidBenchmark
 from .hf_hub import get_model_config
 from .model_loading import load_model
 from .scores import log_scores
+from .speed_benchmark import benchmark_speed
 from .types import SCORE_DICT
 from .utils import (
     block_terminal_output,
@@ -78,6 +79,8 @@ class BenchmarkDataset(ABC):
             metric_cfg.name: evaluate.load(
                 metric_cfg.huggingface_id, cache_dir=self.benchmark_config.cache_dir
             )
+            if metric_cfg.huggingface_id != ""
+            else None
             for metric_cfg in dataset_config.task.metrics
         }
 
@@ -133,11 +136,8 @@ class BenchmarkDataset(ABC):
         # Get the metadata
         metadata_dict = self._get_metadata(model=model, tokenizer=tokenizer)
 
-        # Load the data collator
-        data_collator = self._load_data_collator(tokenizer)
-
         # Set variable with number of iterations
-        num_iter = 10 if not self.benchmark_config.testing else 2
+        num_iter = 10 if not self.benchmark_config.testing else 5
 
         # Set up progress bar
         itr = tqdm(
@@ -146,6 +146,21 @@ class BenchmarkDataset(ABC):
             disable=not self.benchmark_config.progress_bar,
         )
 
+        # If we are running the speed estimation benchmark then call that directly
+        if self.dataset_config.task.name == "speed":
+            all_scores = benchmark_speed(
+                itr=itr,
+                tokenizer=tokenizer,
+                model=model,
+                model_config=model_config,
+                dataset_config=self.dataset_config,
+                benchmark_config=self.benchmark_config,
+            )
+            return all_scores, metadata_dict
+
+        # Load the data collator
+        data_collator = self._load_data_collator(tokenizer)
+
         # Load the data
         train, val, test = self._load_data()
 
@@ -172,9 +187,11 @@ class BenchmarkDataset(ABC):
                 "done."
             )
 
+        # Initialise the `scores` dictionary
+        scores: Dict[str, List[Dict[str, float]]] = defaultdict(list)
+
         bs: int = self.benchmark_config.batch_size
         ga: int = 32 // bs
-        scores: Dict[str, List[Dict[str, float]]] = defaultdict(list)
         for idx in itr:
 
             # Set variable that tracks whether we need to initialize new models in the
@@ -313,14 +330,6 @@ class BenchmarkDataset(ABC):
         else:
             logging_strategy = IntervalStrategy.NO
 
-        # Set variable on whether to use MPS device
-        use_mps_device = (
-            torch.backends.mps.is_available() and not self.benchmark_config.testing
-        )
-
-        # Set batch size variable
-        batch_size = 32 if not self.benchmark_config.testing else 1
-
         # Set seed variable
         seed = 4242 + iteration_idx
 
@@ -335,19 +344,18 @@ class BenchmarkDataset(ABC):
                 eval_steps=30,
                 logging_steps=30,
                 save_steps=30,
-                max_steps=10_000 if not self.benchmark_config.testing else 2,
-                report_to="none",
+                max_steps=10_000 if not self.benchmark_config.testing else 10,
+                report_to=[],
                 save_total_limit=1,
-                per_device_train_batch_size=batch_size,
-                per_device_eval_batch_size=batch_size,
+                per_device_train_batch_size=self.benchmark_config.batch_size,
+                per_device_eval_batch_size=self.benchmark_config.batch_size,
                 learning_rate=2e-5,
                 warmup_ratio=0.01,
                 gradient_accumulation_steps=1,
                 load_best_model_at_end=True,
                 optim=OptimizerNames.ADAMW_TORCH,
                 seed=seed,
-                no_cuda=self.benchmark_config.testing,
-                use_mps_device=use_mps_device,
+                use_mps_device=torch.backends.mps.is_available(),
                 fp16=False,
             )
 
