@@ -192,7 +192,7 @@ class Benchmarker:
                         f"{m_id} could not be benchmarked on "
                         f"{dataset_config.pretty_name}. Skipping."
                     )
-                    logger.debug(f'The error message was "{error_msg}".')
+                    logger.debug(f"The error message was {error_msg!r}.")
                     continue
 
                 # Add the record to the benchmark results
