@@ -117,7 +117,12 @@ def load_model(
             if config.model_type == "deberta-v2":
                 config.pooler_hidden_size = config.hidden_size
 
-            # Otherwise load the model
+            # If we are benchmarking a question answering model then we need to set
+            # the type_vocab_size to 2
+            if supertask == "question-answering":
+                config.type_vocab_size = 2
+
+            # Load the model
             with warnings.catch_warnings():
                 warnings.filterwarnings("ignore", category=UserWarning)
                 model_or_tuple = model_cls_or_none.from_pretrained(
@@ -127,14 +132,23 @@ def load_model(
                     config=config,
                     cache_dir=cache_dir,
                     from_flax=from_flax,
+                    ignore_mismatched_sizes=True,
                 )
             if isinstance(model_or_tuple, tuple):
                 model = model_or_tuple[0]
             else:
                 model = model_or_tuple
 
-    except (OSError, ValueError):
-        msg = (
+    except (OSError, ValueError) as e:
+
+        # Deal with the case where the checkpoint is incorrect
+        if "checkpoint seems to be incorrect" in str(e):
+            raise InvalidBenchmark(
+                f"The model {model_id!r} has an incorrect checkpoint."
+            )
+
+        # Otherwise raise a more generic error
+        raise InvalidBenchmark(
             f"The model {model_id} either does not exist on the Hugging Face Hub, or "
             "it has no frameworks registered, or it is a private model. If it *does* "
             "exist on the Hub and is a public model then please ensure that it has a "
@@ -142,20 +156,20 @@ def load_model(
             "`--use-auth-token` flag and make sure that you are logged in to the Hub "
             "via the `huggingface-cli login` command."
         )
-        raise InvalidBenchmark(msg)
 
     # If the model is a subclass of a RoBERTa model then we have to add a prefix
     # space to the tokens, by the way the model is constructed.
-    prefix = "Roberta" in type(model).__name__ or "GPT" in type(model).__name__
+    prefix_models = ["Roberta", "GPT", "Deberta"]
+    prefix = any(model_type in type(model).__name__ for model_type in prefix_models)
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", category=UserWarning)
         tokenizer: PreTrainedTokenizer = AutoTokenizer.from_pretrained(
             model_id,
             revision=revision,
             use_auth_token=use_auth_token,
-            use_fast=True,
             add_prefix_space=prefix,
             cache_dir=cache_dir,
+            use_fast=True,
             verbose=False,
         )
 
